from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ...._jsii import *

from ..base_group_config import GroupConfig as _GroupConfig_a50a33b0


@jsii.data_type(
    jsii_type="@aws/pdk.monorepo.Syncpack.VersionGroupConfig.Banned",
    jsii_struct_bases=[_GroupConfig_a50a33b0],
    name_mapping={
        "dependencies": "dependencies",
        "dependency_types": "dependencyTypes",
        "label": "label",
        "packages": "packages",
        "specifier_types": "specifierTypes",
        "is_banned": "isBanned",
    },
)
class Banned(_GroupConfig_a50a33b0):
    def __init__(
        self,
        *,
        dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
        dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        packages: typing.Optional[typing.Sequence[builtins.str]] = None,
        specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_banned: builtins.bool,
    ) -> None:
        '''
        :param dependencies: 
        :param dependency_types: 
        :param label: 
        :param packages: 
        :param specifier_types: 
        :param is_banned: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc1f53299a7d9f63a6d97ffe2b4ecbaf045f12e19d0647e17d86f64ddf126f2d)
            check_type(argname="argument dependencies", value=dependencies, expected_type=type_hints["dependencies"])
            check_type(argname="argument dependency_types", value=dependency_types, expected_type=type_hints["dependency_types"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument packages", value=packages, expected_type=type_hints["packages"])
            check_type(argname="argument specifier_types", value=specifier_types, expected_type=type_hints["specifier_types"])
            check_type(argname="argument is_banned", value=is_banned, expected_type=type_hints["is_banned"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "is_banned": is_banned,
        }
        if dependencies is not None:
            self._values["dependencies"] = dependencies
        if dependency_types is not None:
            self._values["dependency_types"] = dependency_types
        if label is not None:
            self._values["label"] = label
        if packages is not None:
            self._values["packages"] = packages
        if specifier_types is not None:
            self._values["specifier_types"] = specifier_types

    @builtins.property
    def dependencies(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependencies")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dependency_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependency_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def packages(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("packages")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def specifier_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("specifier_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_banned(self) -> builtins.bool:
        result = self._values.get("is_banned")
        assert result is not None, "Required property 'is_banned' is missing"
        return typing.cast(builtins.bool, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Banned(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.monorepo.Syncpack.VersionGroupConfig.Ignored",
    jsii_struct_bases=[_GroupConfig_a50a33b0],
    name_mapping={
        "dependencies": "dependencies",
        "dependency_types": "dependencyTypes",
        "label": "label",
        "packages": "packages",
        "specifier_types": "specifierTypes",
        "is_ignored": "isIgnored",
    },
)
class Ignored(_GroupConfig_a50a33b0):
    def __init__(
        self,
        *,
        dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
        dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        packages: typing.Optional[typing.Sequence[builtins.str]] = None,
        specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_ignored: builtins.bool,
    ) -> None:
        '''
        :param dependencies: 
        :param dependency_types: 
        :param label: 
        :param packages: 
        :param specifier_types: 
        :param is_ignored: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62d3ef917d50d34451f7fb4bf5272e9eab337c618f89c3f473bfb7769f337f5a)
            check_type(argname="argument dependencies", value=dependencies, expected_type=type_hints["dependencies"])
            check_type(argname="argument dependency_types", value=dependency_types, expected_type=type_hints["dependency_types"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument packages", value=packages, expected_type=type_hints["packages"])
            check_type(argname="argument specifier_types", value=specifier_types, expected_type=type_hints["specifier_types"])
            check_type(argname="argument is_ignored", value=is_ignored, expected_type=type_hints["is_ignored"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "is_ignored": is_ignored,
        }
        if dependencies is not None:
            self._values["dependencies"] = dependencies
        if dependency_types is not None:
            self._values["dependency_types"] = dependency_types
        if label is not None:
            self._values["label"] = label
        if packages is not None:
            self._values["packages"] = packages
        if specifier_types is not None:
            self._values["specifier_types"] = specifier_types

    @builtins.property
    def dependencies(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependencies")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dependency_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependency_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def packages(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("packages")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def specifier_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("specifier_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_ignored(self) -> builtins.bool:
        result = self._values.get("is_ignored")
        assert result is not None, "Required property 'is_ignored' is missing"
        return typing.cast(builtins.bool, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ignored(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.monorepo.Syncpack.VersionGroupConfig.Pinned",
    jsii_struct_bases=[_GroupConfig_a50a33b0],
    name_mapping={
        "dependencies": "dependencies",
        "dependency_types": "dependencyTypes",
        "label": "label",
        "packages": "packages",
        "specifier_types": "specifierTypes",
        "pin_version": "pinVersion",
    },
)
class Pinned(_GroupConfig_a50a33b0):
    def __init__(
        self,
        *,
        dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
        dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        packages: typing.Optional[typing.Sequence[builtins.str]] = None,
        specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        pin_version: builtins.str,
    ) -> None:
        '''
        :param dependencies: 
        :param dependency_types: 
        :param label: 
        :param packages: 
        :param specifier_types: 
        :param pin_version: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4ae41e45d9c19db7906a4f71a1efa0677e7b8993280036aa9b8a398ac1842e6)
            check_type(argname="argument dependencies", value=dependencies, expected_type=type_hints["dependencies"])
            check_type(argname="argument dependency_types", value=dependency_types, expected_type=type_hints["dependency_types"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument packages", value=packages, expected_type=type_hints["packages"])
            check_type(argname="argument specifier_types", value=specifier_types, expected_type=type_hints["specifier_types"])
            check_type(argname="argument pin_version", value=pin_version, expected_type=type_hints["pin_version"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "pin_version": pin_version,
        }
        if dependencies is not None:
            self._values["dependencies"] = dependencies
        if dependency_types is not None:
            self._values["dependency_types"] = dependency_types
        if label is not None:
            self._values["label"] = label
        if packages is not None:
            self._values["packages"] = packages
        if specifier_types is not None:
            self._values["specifier_types"] = specifier_types

    @builtins.property
    def dependencies(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependencies")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dependency_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependency_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def packages(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("packages")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def specifier_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("specifier_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def pin_version(self) -> builtins.str:
        result = self._values.get("pin_version")
        assert result is not None, "Required property 'pin_version' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Pinned(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.monorepo.Syncpack.VersionGroupConfig.SameRange",
    jsii_struct_bases=[_GroupConfig_a50a33b0],
    name_mapping={
        "dependencies": "dependencies",
        "dependency_types": "dependencyTypes",
        "label": "label",
        "packages": "packages",
        "specifier_types": "specifierTypes",
        "policy": "policy",
    },
)
class SameRange(_GroupConfig_a50a33b0):
    def __init__(
        self,
        *,
        dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
        dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        packages: typing.Optional[typing.Sequence[builtins.str]] = None,
        specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        policy: builtins.str,
    ) -> None:
        '''
        :param dependencies: 
        :param dependency_types: 
        :param label: 
        :param packages: 
        :param specifier_types: 
        :param policy: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9398af03e128e98d2b8ee35307bf7227c5f58a71582d5084203bd40bcaf25c9e)
            check_type(argname="argument dependencies", value=dependencies, expected_type=type_hints["dependencies"])
            check_type(argname="argument dependency_types", value=dependency_types, expected_type=type_hints["dependency_types"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument packages", value=packages, expected_type=type_hints["packages"])
            check_type(argname="argument specifier_types", value=specifier_types, expected_type=type_hints["specifier_types"])
            check_type(argname="argument policy", value=policy, expected_type=type_hints["policy"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "policy": policy,
        }
        if dependencies is not None:
            self._values["dependencies"] = dependencies
        if dependency_types is not None:
            self._values["dependency_types"] = dependency_types
        if label is not None:
            self._values["label"] = label
        if packages is not None:
            self._values["packages"] = packages
        if specifier_types is not None:
            self._values["specifier_types"] = specifier_types

    @builtins.property
    def dependencies(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependencies")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dependency_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependency_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def packages(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("packages")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def specifier_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("specifier_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def policy(self) -> builtins.str:
        result = self._values.get("policy")
        assert result is not None, "Required property 'policy' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SameRange(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.monorepo.Syncpack.VersionGroupConfig.SnappedTo",
    jsii_struct_bases=[_GroupConfig_a50a33b0],
    name_mapping={
        "dependencies": "dependencies",
        "dependency_types": "dependencyTypes",
        "label": "label",
        "packages": "packages",
        "specifier_types": "specifierTypes",
        "snap_to": "snapTo",
    },
)
class SnappedTo(_GroupConfig_a50a33b0):
    def __init__(
        self,
        *,
        dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
        dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        packages: typing.Optional[typing.Sequence[builtins.str]] = None,
        specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        snap_to: typing.Sequence[builtins.str],
    ) -> None:
        '''
        :param dependencies: 
        :param dependency_types: 
        :param label: 
        :param packages: 
        :param specifier_types: 
        :param snap_to: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5597564c05b3ac31df8c26276c3ced91d04f09ee23a89decbaeaa73b9b38d9d3)
            check_type(argname="argument dependencies", value=dependencies, expected_type=type_hints["dependencies"])
            check_type(argname="argument dependency_types", value=dependency_types, expected_type=type_hints["dependency_types"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument packages", value=packages, expected_type=type_hints["packages"])
            check_type(argname="argument specifier_types", value=specifier_types, expected_type=type_hints["specifier_types"])
            check_type(argname="argument snap_to", value=snap_to, expected_type=type_hints["snap_to"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "snap_to": snap_to,
        }
        if dependencies is not None:
            self._values["dependencies"] = dependencies
        if dependency_types is not None:
            self._values["dependency_types"] = dependency_types
        if label is not None:
            self._values["label"] = label
        if packages is not None:
            self._values["packages"] = packages
        if specifier_types is not None:
            self._values["specifier_types"] = specifier_types

    @builtins.property
    def dependencies(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependencies")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dependency_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependency_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def packages(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("packages")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def specifier_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("specifier_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def snap_to(self) -> typing.List[builtins.str]:
        result = self._values.get("snap_to")
        assert result is not None, "Required property 'snap_to' is missing"
        return typing.cast(typing.List[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnappedTo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.monorepo.Syncpack.VersionGroupConfig.Standard",
    jsii_struct_bases=[_GroupConfig_a50a33b0],
    name_mapping={
        "dependencies": "dependencies",
        "dependency_types": "dependencyTypes",
        "label": "label",
        "packages": "packages",
        "specifier_types": "specifierTypes",
        "prefer_version": "preferVersion",
    },
)
class Standard(_GroupConfig_a50a33b0):
    def __init__(
        self,
        *,
        dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
        dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        packages: typing.Optional[typing.Sequence[builtins.str]] = None,
        specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        prefer_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param dependencies: 
        :param dependency_types: 
        :param label: 
        :param packages: 
        :param specifier_types: 
        :param prefer_version: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a0425c02e8891bab22137f821ac48ffc5d54c5bc2ffc9929b81caeb36f42342)
            check_type(argname="argument dependencies", value=dependencies, expected_type=type_hints["dependencies"])
            check_type(argname="argument dependency_types", value=dependency_types, expected_type=type_hints["dependency_types"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument packages", value=packages, expected_type=type_hints["packages"])
            check_type(argname="argument specifier_types", value=specifier_types, expected_type=type_hints["specifier_types"])
            check_type(argname="argument prefer_version", value=prefer_version, expected_type=type_hints["prefer_version"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if dependencies is not None:
            self._values["dependencies"] = dependencies
        if dependency_types is not None:
            self._values["dependency_types"] = dependency_types
        if label is not None:
            self._values["label"] = label
        if packages is not None:
            self._values["packages"] = packages
        if specifier_types is not None:
            self._values["specifier_types"] = specifier_types
        if prefer_version is not None:
            self._values["prefer_version"] = prefer_version

    @builtins.property
    def dependencies(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependencies")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dependency_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dependency_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def packages(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("packages")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def specifier_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("specifier_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def prefer_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("prefer_version")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Standard(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "Banned",
    "Ignored",
    "Pinned",
    "SameRange",
    "SnappedTo",
    "Standard",
]

publication.publish()

def _typecheckingstub__bc1f53299a7d9f63a6d97ffe2b4ecbaf045f12e19d0647e17d86f64ddf126f2d(
    *,
    dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
    dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    label: typing.Optional[builtins.str] = None,
    packages: typing.Optional[typing.Sequence[builtins.str]] = None,
    specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_banned: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62d3ef917d50d34451f7fb4bf5272e9eab337c618f89c3f473bfb7769f337f5a(
    *,
    dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
    dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    label: typing.Optional[builtins.str] = None,
    packages: typing.Optional[typing.Sequence[builtins.str]] = None,
    specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_ignored: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4ae41e45d9c19db7906a4f71a1efa0677e7b8993280036aa9b8a398ac1842e6(
    *,
    dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
    dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    label: typing.Optional[builtins.str] = None,
    packages: typing.Optional[typing.Sequence[builtins.str]] = None,
    specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    pin_version: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9398af03e128e98d2b8ee35307bf7227c5f58a71582d5084203bd40bcaf25c9e(
    *,
    dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
    dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    label: typing.Optional[builtins.str] = None,
    packages: typing.Optional[typing.Sequence[builtins.str]] = None,
    specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    policy: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5597564c05b3ac31df8c26276c3ced91d04f09ee23a89decbaeaa73b9b38d9d3(
    *,
    dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
    dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    label: typing.Optional[builtins.str] = None,
    packages: typing.Optional[typing.Sequence[builtins.str]] = None,
    specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    snap_to: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a0425c02e8891bab22137f821ac48ffc5d54c5bc2ffc9929b81caeb36f42342(
    *,
    dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
    dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    label: typing.Optional[builtins.str] = None,
    packages: typing.Optional[typing.Sequence[builtins.str]] = None,
    specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    prefer_version: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass



from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ..._jsii import *

from .custom_type_config import (
    NameAndVersionProps as _NameAndVersionProps_24403af6,
    NamedVersionString as _NamedVersionString_3bf188be,
    UnnamedVersionString as _UnnamedVersionString_b2b8403e,
    VersionsByName as _VersionsByName_1c190b74,
)
from .semver_group_config import (
    Disabled as _Disabled_e47b7b80,
    Ignored as _Ignored_c00736b0,
    WithRange as _WithRange_5c9a8aff,
)
from .version_group_config import (
    Banned as _Banned_d684f005,
    Ignored as _Ignored_7ebad223,
    Pinned as _Pinned_0b9cc84e,
    SameRange as _SameRange_2cff5247,
    SnappedTo as _SnappedTo_3347d5ad,
    Standard as _Standard_f8437087,
)


@jsii.data_type(
    jsii_type="@aws/pdk.monorepo.Syncpack.CliConfig",
    jsii_struct_bases=[],
    name_mapping={
        "filter": "filter",
        "indent": "indent",
        "source": "source",
        "specs": "specs",
        "types": "types",
        "config_path": "configPath",
    },
)
class CliConfig:
    def __init__(
        self,
        *,
        filter: builtins.str,
        indent: builtins.str,
        source: typing.Sequence[builtins.str],
        specs: builtins.str,
        types: builtins.str,
        config_path: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param filter: 
        :param indent: 
        :param source: 
        :param specs: 
        :param types: 
        :param config_path: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c95dfa5cb9060b85d0ddf6297893e1bc2c5b48787cf239c9d2b9bd81046c919)
            check_type(argname="argument filter", value=filter, expected_type=type_hints["filter"])
            check_type(argname="argument indent", value=indent, expected_type=type_hints["indent"])
            check_type(argname="argument source", value=source, expected_type=type_hints["source"])
            check_type(argname="argument specs", value=specs, expected_type=type_hints["specs"])
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
            check_type(argname="argument config_path", value=config_path, expected_type=type_hints["config_path"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "filter": filter,
            "indent": indent,
            "source": source,
            "specs": specs,
            "types": types,
        }
        if config_path is not None:
            self._values["config_path"] = config_path

    @builtins.property
    def filter(self) -> builtins.str:
        result = self._values.get("filter")
        assert result is not None, "Required property 'filter' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def indent(self) -> builtins.str:
        result = self._values.get("indent")
        assert result is not None, "Required property 'indent' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def source(self) -> typing.List[builtins.str]:
        result = self._values.get("source")
        assert result is not None, "Required property 'source' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def specs(self) -> builtins.str:
        result = self._values.get("specs")
        assert result is not None, "Required property 'specs' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def types(self) -> builtins.str:
        result = self._values.get("types")
        assert result is not None, "Required property 'types' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def config_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("config_path")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CliConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.monorepo.Syncpack.SyncpackConfig",
    jsii_struct_bases=[],
    name_mapping={
        "custom_types": "customTypes",
        "dependency_types": "dependencyTypes",
        "filter": "filter",
        "format_bugs": "formatBugs",
        "format_repository": "formatRepository",
        "indent": "indent",
        "lint_formatting": "lintFormatting",
        "lint_semver_ranges": "lintSemverRanges",
        "lint_versions": "lintVersions",
        "semver_groups": "semverGroups",
        "sort_az": "sortAz",
        "sort_exports": "sortExports",
        "sort_first": "sortFirst",
        "sort_packages": "sortPackages",
        "source": "source",
        "specifier_types": "specifierTypes",
        "version_groups": "versionGroups",
    },
)
class SyncpackConfig:
    def __init__(
        self,
        *,
        custom_types: typing.Optional[typing.Mapping[builtins.str, typing.Union[typing.Union[_NameAndVersionProps_24403af6, typing.Dict[builtins.str, typing.Any]], typing.Union[_NamedVersionString_3bf188be, typing.Dict[builtins.str, typing.Any]], typing.Union[_UnnamedVersionString_b2b8403e, typing.Dict[builtins.str, typing.Any]], typing.Union[_VersionsByName_1c190b74, typing.Dict[builtins.str, typing.Any]]]]] = None,
        dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        filter: typing.Optional[builtins.str] = None,
        format_bugs: typing.Optional[builtins.bool] = None,
        format_repository: typing.Optional[builtins.bool] = None,
        indent: typing.Optional[builtins.str] = None,
        lint_formatting: typing.Optional[builtins.bool] = None,
        lint_semver_ranges: typing.Optional[builtins.bool] = None,
        lint_versions: typing.Optional[builtins.bool] = None,
        semver_groups: typing.Optional[typing.Sequence[typing.Union[typing.Union[_Disabled_e47b7b80, typing.Dict[builtins.str, typing.Any]], typing.Union[_Ignored_c00736b0, typing.Dict[builtins.str, typing.Any]], typing.Union[_WithRange_5c9a8aff, typing.Dict[builtins.str, typing.Any]]]]] = None,
        sort_az: typing.Optional[typing.Sequence[builtins.str]] = None,
        sort_exports: typing.Optional[typing.Sequence[builtins.str]] = None,
        sort_first: typing.Optional[typing.Sequence[builtins.str]] = None,
        sort_packages: typing.Optional[builtins.bool] = None,
        source: typing.Optional[typing.Sequence[builtins.str]] = None,
        specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
        version_groups: typing.Optional[typing.Sequence[typing.Union[typing.Union[_Banned_d684f005, typing.Dict[builtins.str, typing.Any]], typing.Union[_Ignored_7ebad223, typing.Dict[builtins.str, typing.Any]], typing.Union[_Pinned_0b9cc84e, typing.Dict[builtins.str, typing.Any]], typing.Union[_SnappedTo_3347d5ad, typing.Dict[builtins.str, typing.Any]], typing.Union[_SameRange_2cff5247, typing.Dict[builtins.str, typing.Any]], typing.Union[_Standard_f8437087, typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''Configuration for Syncpack.

        :param custom_types: 
        :param dependency_types: 
        :param filter: 
        :param format_bugs: 
        :param format_repository: 
        :param indent: 
        :param lint_formatting: 
        :param lint_semver_ranges: 
        :param lint_versions: 
        :param semver_groups: 
        :param sort_az: 
        :param sort_exports: 
        :param sort_first: 
        :param sort_packages: 
        :param source: 
        :param specifier_types: 
        :param version_groups: 

        :see: https://jamiemason.github.io/syncpack
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f876284f102219bc3c8a77a28983d485f44704e2cbc7da1c21b97df1541724c7)
            check_type(argname="argument custom_types", value=custom_types, expected_type=type_hints["custom_types"])
            check_type(argname="argument dependency_types", value=dependency_types, expected_type=type_hints["dependency_types"])
            check_type(argname="argument filter", value=filter, expected_type=type_hints["filter"])
            check_type(argname="argument format_bugs", value=format_bugs, expected_type=type_hints["format_bugs"])
            check_type(argname="argument format_repository", value=format_repository, expected_type=type_hints["format_repository"])
            check_type(argname="argument indent", value=indent, expected_type=type_hints["indent"])
            check_type(argname="argument lint_formatting", value=lint_formatting, expected_type=type_hints["lint_formatting"])
            check_type(argname="argument lint_semver_ranges", value=lint_semver_ranges, expected_type=type_hints["lint_semver_ranges"])
            check_type(argname="argument lint_versions", value=lint_versions, expected_type=type_hints["lint_versions"])
            check_type(argname="argument semver_groups", value=semver_groups, expected_type=type_hints["semver_groups"])
            check_type(argname="argument sort_az", value=sort_az, expected_type=type_hints["sort_az"])
            check_type(argname="argument sort_exports", value=sort_exports, expected_type=type_hints["sort_exports"])
            check_type(argname="argument sort_first", value=sort_first, expected_type=type_hints["sort_first"])
            check_type(argname="argument sort_packages", value=sort_packages, expected_type=type_hints["sort_packages"])
            check_type(argname="argument source", value=source, expected_type=type_hints["source"])
            check_type(argname="argument specifier_types", value=specifier_types, expected_type=type_hints["specifier_types"])
            check_type(argname="argument version_groups", value=version_groups, expected_type=type_hints["version_groups"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_types is not None:
            self._values["custom_types"] = custom_types
        if dependency_types is not None:
            self._values["dependency_types"] = dependency_types
        if filter is not None:
            self._values["filter"] = filter
        if format_bugs is not None:
            self._values["format_bugs"] = format_bugs
        if format_repository is not None:
            self._values["format_repository"] = format_repository
        if indent is not None:
            self._values["indent"] = indent
        if lint_formatting is not None:
            self._values["lint_formatting"] = lint_formatting
        if lint_semver_ranges is not None:
            self._values["lint_semver_ranges"] = lint_semver_ranges
        if lint_versions is not None:
            self._values["lint_versions"] = lint_versions
        if semver_groups is not None:
            self._values["semver_groups"] = semver_groups
        if sort_az is not None:
            self._values["sort_az"] = sort_az
        if sort_exports is not None:
            self._values["sort_exports"] = sort_exports
        if sort_first is not None:
            self._values["sort_first"] = sort_first
        if sort_packages is not None:
            self._values["sort_packages"] = sort_packages
        if source is not None:
            self._values["source"] = source
        if specifier_types is not None:
            self._values["specifier_types"] = specifier_types
        if version_groups is not None:
            self._values["version_groups"] = version_groups

    @builtins.property
    def custom_types(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[_NameAndVersionProps_24403af6, _NamedVersionString_3bf188be, _UnnamedVersionString_b2b8403e, _VersionsByName_1c190b74]]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/custom-types
        '''
        result = self._values.get("custom_types")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[_NameAndVersionProps_24403af6, _NamedVersionString_3bf188be, _UnnamedVersionString_b2b8403e, _VersionsByName_1c190b74]]], result)

    @builtins.property
    def dependency_types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/dependency-types
        '''
        result = self._values.get("dependency_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def filter(self) -> typing.Optional[builtins.str]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/filter
        '''
        result = self._values.get("filter")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def format_bugs(self) -> typing.Optional[builtins.bool]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/format-bugs
        '''
        result = self._values.get("format_bugs")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def format_repository(self) -> typing.Optional[builtins.bool]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/format-repository
        '''
        result = self._values.get("format_repository")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def indent(self) -> typing.Optional[builtins.str]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/indent
        '''
        result = self._values.get("indent")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def lint_formatting(self) -> typing.Optional[builtins.bool]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/lint-formatting
        '''
        result = self._values.get("lint_formatting")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def lint_semver_ranges(self) -> typing.Optional[builtins.bool]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/lint-semver-ranges
        '''
        result = self._values.get("lint_semver_ranges")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def lint_versions(self) -> typing.Optional[builtins.bool]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/lint-versions
        '''
        result = self._values.get("lint_versions")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def semver_groups(
        self,
    ) -> typing.Optional[typing.List[typing.Union[_Disabled_e47b7b80, _Ignored_c00736b0, _WithRange_5c9a8aff]]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/semver-groups
        '''
        result = self._values.get("semver_groups")
        return typing.cast(typing.Optional[typing.List[typing.Union[_Disabled_e47b7b80, _Ignored_c00736b0, _WithRange_5c9a8aff]]], result)

    @builtins.property
    def sort_az(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/sort-az
        '''
        result = self._values.get("sort_az")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def sort_exports(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/sort-exports
        '''
        result = self._values.get("sort_exports")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def sort_first(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/sort-first
        '''
        result = self._values.get("sort_first")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def sort_packages(self) -> typing.Optional[builtins.bool]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/sort-packages
        '''
        result = self._values.get("sort_packages")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def source(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/source
        '''
        result = self._values.get("source")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def specifier_types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/specifier-types
        '''
        result = self._values.get("specifier_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def version_groups(
        self,
    ) -> typing.Optional[typing.List[typing.Union[_Banned_d684f005, _Ignored_7ebad223, _Pinned_0b9cc84e, _SnappedTo_3347d5ad, _SameRange_2cff5247, _Standard_f8437087]]]:
        '''
        :see: https://jamiemason.github.io/syncpack/config/version-groups
        '''
        result = self._values.get("version_groups")
        return typing.cast(typing.Optional[typing.List[typing.Union[_Banned_d684f005, _Ignored_7ebad223, _Pinned_0b9cc84e, _SnappedTo_3347d5ad, _SameRange_2cff5247, _Standard_f8437087]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SyncpackConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "CliConfig",
    "SyncpackConfig",
    "base_group_config",
    "custom_type_config",
    "semver_group_config",
    "version_group_config",
]

publication.publish()

# Loading modules to ensure their types are registered with the jsii runtime library
from . import base_group_config
from . import custom_type_config
from . import semver_group_config
from . import version_group_config

def _typecheckingstub__6c95dfa5cb9060b85d0ddf6297893e1bc2c5b48787cf239c9d2b9bd81046c919(
    *,
    filter: builtins.str,
    indent: builtins.str,
    source: typing.Sequence[builtins.str],
    specs: builtins.str,
    types: builtins.str,
    config_path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f876284f102219bc3c8a77a28983d485f44704e2cbc7da1c21b97df1541724c7(
    *,
    custom_types: typing.Optional[typing.Mapping[builtins.str, typing.Union[typing.Union[_NameAndVersionProps_24403af6, typing.Dict[builtins.str, typing.Any]], typing.Union[_NamedVersionString_3bf188be, typing.Dict[builtins.str, typing.Any]], typing.Union[_UnnamedVersionString_b2b8403e, typing.Dict[builtins.str, typing.Any]], typing.Union[_VersionsByName_1c190b74, typing.Dict[builtins.str, typing.Any]]]]] = None,
    dependency_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    filter: typing.Optional[builtins.str] = None,
    format_bugs: typing.Optional[builtins.bool] = None,
    format_repository: typing.Optional[builtins.bool] = None,
    indent: typing.Optional[builtins.str] = None,
    lint_formatting: typing.Optional[builtins.bool] = None,
    lint_semver_ranges: typing.Optional[builtins.bool] = None,
    lint_versions: typing.Optional[builtins.bool] = None,
    semver_groups: typing.Optional[typing.Sequence[typing.Union[typing.Union[_Disabled_e47b7b80, typing.Dict[builtins.str, typing.Any]], typing.Union[_Ignored_c00736b0, typing.Dict[builtins.str, typing.Any]], typing.Union[_WithRange_5c9a8aff, typing.Dict[builtins.str, typing.Any]]]]] = None,
    sort_az: typing.Optional[typing.Sequence[builtins.str]] = None,
    sort_exports: typing.Optional[typing.Sequence[builtins.str]] = None,
    sort_first: typing.Optional[typing.Sequence[builtins.str]] = None,
    sort_packages: typing.Optional[builtins.bool] = None,
    source: typing.Optional[typing.Sequence[builtins.str]] = None,
    specifier_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    version_groups: typing.Optional[typing.Sequence[typing.Union[typing.Union[_Banned_d684f005, typing.Dict[builtins.str, typing.Any]], typing.Union[_Ignored_7ebad223, typing.Dict[builtins.str, typing.Any]], typing.Union[_Pinned_0b9cc84e, typing.Dict[builtins.str, typing.Any]], typing.Union[_SnappedTo_3347d5ad, typing.Dict[builtins.str, typing.Any]], typing.Union[_SameRange_2cff5247, typing.Dict[builtins.str, typing.Any]], typing.Union[_Standard_f8437087, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass



from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from .._jsii import *

import aws_cdk as _aws_cdk_ceddda9d
import aws_cdk.cx_api as _aws_cdk_cx_api_ceddda9d
import cdk_nag as _cdk_nag_263d9695
import constructs as _constructs_77d1e7e8


class AwsPrototypingChecks(
    _cdk_nag_263d9695.NagPack,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws/pdk.pdk_nag.AwsPrototypingChecks",
):
    '''Check best practices for prototypes.'''

    def __init__(
        self,
        *,
        additional_loggers: typing.Optional[typing.Sequence[_cdk_nag_263d9695.INagLogger]] = None,
        log_ignores: typing.Optional[builtins.bool] = None,
        report_formats: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagReportFormat]] = None,
        reports: typing.Optional[builtins.bool] = None,
        suppression_ignore_condition: typing.Optional[_cdk_nag_263d9695.INagSuppressionIgnore] = None,
        verbose: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param additional_loggers: Additional NagLoggers for logging rule validation outputs.
        :param log_ignores: Whether or not to log suppressed rule violations as informational messages (default: false).
        :param report_formats: If reports are enabled, the output formats of compliance reports in the App's output directory (default: only CSV).
        :param reports: Whether or not to generate compliance reports for applied Stacks in the App's output directory (default: true).
        :param suppression_ignore_condition: Conditionally prevent rules from being suppressed (default: no user provided condition).
        :param verbose: Whether or not to enable extended explanatory descriptions on warning, error, and logged ignore messages (default: false).
        '''
        props = _cdk_nag_263d9695.NagPackProps(
            additional_loggers=additional_loggers,
            log_ignores=log_ignores,
            report_formats=report_formats,
            reports=reports,
            suppression_ignore_condition=suppression_ignore_condition,
            verbose=verbose,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="visit")
    def visit(self, node: _constructs_77d1e7e8.IConstruct) -> None:
        '''Check if CfnResource and apply rules.

        :param node: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8aa12b05f34ae8c5f2ba1473e38e19d866fb8f4b520412005d0fe346b7fb8e7)
            check_type(argname="argument node", value=node, expected_type=type_hints["node"])
        return typing.cast(None, jsii.invoke(self, "visit", [node]))


@jsii.data_type(
    jsii_type="@aws/pdk.pdk_nag.ExtendedNagResult",
    jsii_struct_bases=[],
    name_mapping={
        "compliance": "compliance",
        "nag_pack_name": "nagPackName",
        "resource": "resource",
        "rule_explanation": "ruleExplanation",
        "rule_id": "ruleId",
        "rule_info": "ruleInfo",
        "rule_level": "ruleLevel",
        "rule_original_name": "ruleOriginalName",
        "error_message": "errorMessage",
        "finding_id": "findingId",
        "suppression_reason": "suppressionReason",
    },
)
class ExtendedNagResult:
    def __init__(
        self,
        *,
        compliance: "NagResultCompliance",
        nag_pack_name: builtins.str,
        resource: _aws_cdk_ceddda9d.CfnResource,
        rule_explanation: builtins.str,
        rule_id: builtins.str,
        rule_info: builtins.str,
        rule_level: _cdk_nag_263d9695.NagMessageLevel,
        rule_original_name: builtins.str,
        error_message: typing.Optional[builtins.str] = None,
        finding_id: typing.Optional[builtins.str] = None,
        suppression_reason: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Represents the result of applying a CDK Nag rule to a resource.

        :param compliance: Compliance status of the rule against the resource.
        :param nag_pack_name: The name of the nag pack this rule is from.
        :param resource: The resource the rule was applied to.
        :param rule_explanation: Why the rule exists.
        :param rule_id: The ID of the rule in this nag pack.
        :param rule_info: Why the rule was triggered.
        :param rule_level: The severity level of the rule.
        :param rule_original_name: The original name of the rule (regardless of nag pack).
        :param error_message: The error that was thrown, only set for error results.
        :param finding_id: The finding that was checked, only set for non-compliant results.
        :param suppression_reason: The reason the rule was suppressed, if any.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8449c5c2cfffdf3f73061d623bdbfb9a6f8c1a04846ab12f3c08d754a61977e5)
            check_type(argname="argument compliance", value=compliance, expected_type=type_hints["compliance"])
            check_type(argname="argument nag_pack_name", value=nag_pack_name, expected_type=type_hints["nag_pack_name"])
            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            check_type(argname="argument rule_explanation", value=rule_explanation, expected_type=type_hints["rule_explanation"])
            check_type(argname="argument rule_id", value=rule_id, expected_type=type_hints["rule_id"])
            check_type(argname="argument rule_info", value=rule_info, expected_type=type_hints["rule_info"])
            check_type(argname="argument rule_level", value=rule_level, expected_type=type_hints["rule_level"])
            check_type(argname="argument rule_original_name", value=rule_original_name, expected_type=type_hints["rule_original_name"])
            check_type(argname="argument error_message", value=error_message, expected_type=type_hints["error_message"])
            check_type(argname="argument finding_id", value=finding_id, expected_type=type_hints["finding_id"])
            check_type(argname="argument suppression_reason", value=suppression_reason, expected_type=type_hints["suppression_reason"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compliance": compliance,
            "nag_pack_name": nag_pack_name,
            "resource": resource,
            "rule_explanation": rule_explanation,
            "rule_id": rule_id,
            "rule_info": rule_info,
            "rule_level": rule_level,
            "rule_original_name": rule_original_name,
        }
        if error_message is not None:
            self._values["error_message"] = error_message
        if finding_id is not None:
            self._values["finding_id"] = finding_id
        if suppression_reason is not None:
            self._values["suppression_reason"] = suppression_reason

    @builtins.property
    def compliance(self) -> "NagResultCompliance":
        '''Compliance status of the rule against the resource.'''
        result = self._values.get("compliance")
        assert result is not None, "Required property 'compliance' is missing"
        return typing.cast("NagResultCompliance", result)

    @builtins.property
    def nag_pack_name(self) -> builtins.str:
        '''The name of the nag pack this rule is from.'''
        result = self._values.get("nag_pack_name")
        assert result is not None, "Required property 'nag_pack_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource(self) -> _aws_cdk_ceddda9d.CfnResource:
        '''The resource the rule was applied to.'''
        result = self._values.get("resource")
        assert result is not None, "Required property 'resource' is missing"
        return typing.cast(_aws_cdk_ceddda9d.CfnResource, result)

    @builtins.property
    def rule_explanation(self) -> builtins.str:
        '''Why the rule exists.'''
        result = self._values.get("rule_explanation")
        assert result is not None, "Required property 'rule_explanation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def rule_id(self) -> builtins.str:
        '''The ID of the rule in this nag pack.'''
        result = self._values.get("rule_id")
        assert result is not None, "Required property 'rule_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def rule_info(self) -> builtins.str:
        '''Why the rule was triggered.'''
        result = self._values.get("rule_info")
        assert result is not None, "Required property 'rule_info' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def rule_level(self) -> _cdk_nag_263d9695.NagMessageLevel:
        '''The severity level of the rule.'''
        result = self._values.get("rule_level")
        assert result is not None, "Required property 'rule_level' is missing"
        return typing.cast(_cdk_nag_263d9695.NagMessageLevel, result)

    @builtins.property
    def rule_original_name(self) -> builtins.str:
        '''The original name of the rule (regardless of nag pack).'''
        result = self._values.get("rule_original_name")
        assert result is not None, "Required property 'rule_original_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def error_message(self) -> typing.Optional[builtins.str]:
        '''The error that was thrown, only set for error results.'''
        result = self._values.get("error_message")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def finding_id(self) -> typing.Optional[builtins.str]:
        '''The finding that was checked, only set for non-compliant results.'''
        result = self._values.get("finding_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def suppression_reason(self) -> typing.Optional[builtins.str]:
        '''The reason the rule was suppressed, if any.'''
        result = self._values.get("suppression_reason")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExtendedNagResult(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.pdk_nag.Message",
    jsii_struct_bases=[],
    name_mapping={
        "message_description": "messageDescription",
        "message_type": "messageType",
    },
)
class Message:
    def __init__(
        self,
        *,
        message_description: builtins.str,
        message_type: builtins.str,
    ) -> None:
        '''Message instance.

        :param message_description: Message description.
        :param message_type: Message type as returned from cdk-nag.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c93182a4922d7452f57be229082f9c3d5dd9ca71941154fcdac4df76b43c528)
            check_type(argname="argument message_description", value=message_description, expected_type=type_hints["message_description"])
            check_type(argname="argument message_type", value=message_type, expected_type=type_hints["message_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "message_description": message_description,
            "message_type": message_type,
        }

    @builtins.property
    def message_description(self) -> builtins.str:
        '''Message description.'''
        result = self._values.get("message_description")
        assert result is not None, "Required property 'message_description' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def message_type(self) -> builtins.str:
        '''Message type as returned from cdk-nag.'''
        result = self._values.get("message_type")
        assert result is not None, "Required property 'message_type' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Message(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.pdk_nag.NagResult",
    jsii_struct_bases=[],
    name_mapping={"messages": "messages", "resource": "resource"},
)
class NagResult:
    def __init__(
        self,
        *,
        messages: typing.Sequence[typing.Union[Message, typing.Dict[builtins.str, typing.Any]]],
        resource: builtins.str,
    ) -> None:
        '''Nag result.

        :param messages: List of messages.
        :param resource: Resource which triggered the message.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83f28e99b6450320d049052294b8732c9914971212aecba15ae4e76747213125)
            check_type(argname="argument messages", value=messages, expected_type=type_hints["messages"])
            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "messages": messages,
            "resource": resource,
        }

    @builtins.property
    def messages(self) -> typing.List[Message]:
        '''List of messages.'''
        result = self._values.get("messages")
        assert result is not None, "Required property 'messages' is missing"
        return typing.cast(typing.List[Message], result)

    @builtins.property
    def resource(self) -> builtins.str:
        '''Resource which triggered the message.'''
        result = self._values.get("resource")
        assert result is not None, "Required property 'resource' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NagResult(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="@aws/pdk.pdk_nag.NagResultCompliance")
class NagResultCompliance(enum.Enum):
    '''Possible statuses for nag rules.'''

    COMPLIANT = "COMPLIANT"
    '''Resource complies with the rule.'''
    NON_COMPLIANT = "NON_COMPLIANT"
    '''Resource does not comply with the rule.'''
    NON_COMPLIANT_SUPPRESSED = "NON_COMPLIANT_SUPPRESSED"
    '''Resource does not comply with the rule, but the rule was suppressed.'''
    ERROR = "ERROR"
    '''An error occurred applying the rule.'''
    ERROR_SUPPRESSED = "ERROR_SUPPRESSED"
    '''An error occurred applying the rule, but the rule was suppressed.'''
    NOT_APPLICABLE = "NOT_APPLICABLE"
    '''The rule is not applicable to the resource.'''


class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws/pdk.pdk_nag.PDKNag"):
    '''Helper for create a Nag Enabled App.'''

    def __init__(self) -> None:
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="addResourceSuppressionsByPathNoThrow")
    @builtins.classmethod
    def add_resource_suppressions_by_path_no_throw(
        cls,
        stack: _aws_cdk_ceddda9d.Stack,
        path: builtins.str,
        suppressions: typing.Sequence[typing.Union[_cdk_nag_263d9695.NagPackSuppression, typing.Dict[builtins.str, typing.Any]]],
        apply_to_children: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''Wrapper around NagSuppressions which does not throw.

        :param stack: stack instance.
        :param path: resource path.
        :param suppressions: list of suppressions to apply.
        :param apply_to_children: whether to apply to children.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6df4154748281a399576171b2f69c41577cb5a8b1ea4b026921fbf1e7feed914)
            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            check_type(argname="argument suppressions", value=suppressions, expected_type=type_hints["suppressions"])
            check_type(argname="argument apply_to_children", value=apply_to_children, expected_type=type_hints["apply_to_children"])
        return typing.cast(None, jsii.sinvoke(cls, "addResourceSuppressionsByPathNoThrow", [stack, path, suppressions, apply_to_children]))

    @jsii.member(jsii_name="app")
    @builtins.classmethod
    def app(
        cls,
        *,
        fail_on_error: typing.Optional[builtins.bool] = None,
        fail_on_warning: typing.Optional[builtins.bool] = None,
        nag_packs: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagPack]] = None,
        analytics_reporting: typing.Optional[builtins.bool] = None,
        auto_synth: typing.Optional[builtins.bool] = None,
        context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        default_stack_synthesizer: typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer] = None,
        outdir: typing.Optional[builtins.str] = None,
        policy_validation_beta1: typing.Optional[typing.Sequence[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]] = None,
        post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        stack_traces: typing.Optional[builtins.bool] = None,
        tree_metadata: typing.Optional[builtins.bool] = None,
    ) -> "PDKNagApp":
        '''Returns an instance of an App with Nag enabled.

        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
        :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
        :param nag_packs: Custom nag packs to execute. Default: DEFAULT_NAG_PACKS
        :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
        :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
        :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
        :param default_stack_synthesizer: The stack synthesizer to use by default for all Stacks in the App. The Stack Synthesizer controls aspects of synthesis and deployment, like how assets are referenced and what IAM roles to use. For more information, see the README of the main CDK package. Default: - A ``DefaultStackSynthesizer`` with default settings
        :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
        :param policy_validation_beta1: Validation plugins to run after synthesis. Default: - no validation plugins
        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
        :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
        :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
        '''
        props = PDKNagAppProps(
            fail_on_error=fail_on_error,
            fail_on_warning=fail_on_warning,
            nag_packs=nag_packs,
            analytics_reporting=analytics_reporting,
            auto_synth=auto_synth,
            context=context,
            default_stack_synthesizer=default_stack_synthesizer,
            outdir=outdir,
            policy_validation_beta1=policy_validation_beta1,
            post_cli_context=post_cli_context,
            stack_traces=stack_traces,
            tree_metadata=tree_metadata,
        )

        return typing.cast("PDKNagApp", jsii.sinvoke(cls, "app", [props]))

    @jsii.member(jsii_name="getStackAccountRegex")
    @builtins.classmethod
    def get_stack_account_regex(cls, stack: _aws_cdk_ceddda9d.Stack) -> builtins.str:
        '''Returns a stack account regex.

        :param stack: stack instance.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9c7b8ca6e6cf7067508e077a349f6970a468d6f27683ecf2baab2767c4a24e6)
            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
        return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackAccountRegex", [stack]))

    @jsii.member(jsii_name="getStackPartitionRegex")
    @builtins.classmethod
    def get_stack_partition_regex(cls, stack: _aws_cdk_ceddda9d.Stack) -> builtins.str:
        '''Returns a stack partition regex.

        :param stack: stack instance.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0aa0bbf9e40945577406f43f4ea42623d4fe13e5e55279a3613263349deeea63)
            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
        return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackPartitionRegex", [stack]))

    @jsii.member(jsii_name="getStackPrefix")
    @builtins.classmethod
    def get_stack_prefix(cls, stack: _aws_cdk_ceddda9d.Stack) -> builtins.str:
        '''Returns a prefix comprising of a delimited set of Stack Ids.

        For example: StackA/NestedStackB/

        :param stack: stack instance.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3571ab007307dce3ff9ffc4cbe7060b3eb33d9a5019948d82aca2dd1edf04c18)
            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
        return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackPrefix", [stack]))

    @jsii.member(jsii_name="getStackRegionRegex")
    @builtins.classmethod
    def get_stack_region_regex(cls, stack: _aws_cdk_ceddda9d.Stack) -> builtins.str:
        '''Returns a stack region regex.

        :param stack: stack instance.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f9f55608ad622f385b97d568c1b49a24059612e0fe4dde7d461d193d8779f26)
            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
        return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackRegionRegex", [stack]))


class PDKNagApp(
    _aws_cdk_ceddda9d.App,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws/pdk.pdk_nag.PDKNagApp",
):
    '''
    :inheritDoc: true
    '''

    def __init__(
        self,
        *,
        fail_on_error: typing.Optional[builtins.bool] = None,
        fail_on_warning: typing.Optional[builtins.bool] = None,
        nag_packs: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagPack]] = None,
        analytics_reporting: typing.Optional[builtins.bool] = None,
        auto_synth: typing.Optional[builtins.bool] = None,
        context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        default_stack_synthesizer: typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer] = None,
        outdir: typing.Optional[builtins.str] = None,
        policy_validation_beta1: typing.Optional[typing.Sequence[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]] = None,
        post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        stack_traces: typing.Optional[builtins.bool] = None,
        tree_metadata: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
        :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
        :param nag_packs: Custom nag packs to execute. Default: DEFAULT_NAG_PACKS
        :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
        :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
        :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
        :param default_stack_synthesizer: The stack synthesizer to use by default for all Stacks in the App. The Stack Synthesizer controls aspects of synthesis and deployment, like how assets are referenced and what IAM roles to use. For more information, see the README of the main CDK package. Default: - A ``DefaultStackSynthesizer`` with default settings
        :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
        :param policy_validation_beta1: Validation plugins to run after synthesis. Default: - no validation plugins
        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
        :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
        :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
        '''
        props = PDKNagAppProps(
            fail_on_error=fail_on_error,
            fail_on_warning=fail_on_warning,
            nag_packs=nag_packs,
            analytics_reporting=analytics_reporting,
            auto_synth=auto_synth,
            context=context,
            default_stack_synthesizer=default_stack_synthesizer,
            outdir=outdir,
            policy_validation_beta1=policy_validation_beta1,
            post_cli_context=post_cli_context,
            stack_traces=stack_traces,
            tree_metadata=tree_metadata,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="addExtendedNagResults")
    def add_extended_nag_results(self, *results: ExtendedNagResult) -> None:
        '''
        :param results: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2fcf25e53176b62e6528f199f19b5eb0ba7082819a349f5a61264769c40505e)
            check_type(argname="argument results", value=results, expected_type=typing.Tuple[type_hints["results"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast(None, jsii.invoke(self, "addExtendedNagResults", [*results]))

    @jsii.member(jsii_name="addNagResult")
    def add_nag_result(
        self,
        *,
        messages: typing.Sequence[typing.Union[Message, typing.Dict[builtins.str, typing.Any]]],
        resource: builtins.str,
    ) -> None:
        '''
        :param messages: List of messages.
        :param resource: Resource which triggered the message.
        '''
        result = NagResult(messages=messages, resource=resource)

        return typing.cast(None, jsii.invoke(self, "addNagResult", [result]))

    @jsii.member(jsii_name="extendedNagResults")
    def extended_nag_results(self) -> typing.List[ExtendedNagResult]:
        '''Returns a list of ExtendedNagResult.

        Note: app.synth() must be called before this to retrieve results.
        '''
        return typing.cast(typing.List[ExtendedNagResult], jsii.invoke(self, "extendedNagResults", []))

    @jsii.member(jsii_name="nagResults")
    def nag_results(self) -> typing.List[NagResult]:
        '''Returns a list of NagResult.

        Note: app.synth() must be called before this to retrieve results.
        '''
        return typing.cast(typing.List[NagResult], jsii.invoke(self, "nagResults", []))

    @jsii.member(jsii_name="synth")
    def synth(
        self,
        *,
        force: typing.Optional[builtins.bool] = None,
        skip_validation: typing.Optional[builtins.bool] = None,
        validate_on_synthesis: typing.Optional[builtins.bool] = None,
    ) -> _aws_cdk_cx_api_ceddda9d.CloudAssembly:
        '''Synthesize this stage into a cloud assembly.

        Once an assembly has been synthesized, it cannot be modified. Subsequent
        calls will return the same assembly.

        :param force: Force a re-synth, even if the stage has already been synthesized. This is used by tests to allow for incremental verification of the output. Do not use in production. Default: false
        :param skip_validation: Should we skip construct validation. Default: - false
        :param validate_on_synthesis: Whether the stack should be validated after synthesis to check for error metadata. Default: - false
        '''
        options = _aws_cdk_ceddda9d.StageSynthesisOptions(
            force=force,
            skip_validation=skip_validation,
            validate_on_synthesis=validate_on_synthesis,
        )

        return typing.cast(_aws_cdk_cx_api_ceddda9d.CloudAssembly, jsii.invoke(self, "synth", [options]))

    @builtins.property
    @jsii.member(jsii_name="nagPacks")
    def nag_packs(self) -> typing.List[_cdk_nag_263d9695.NagPack]:
        return typing.cast(typing.List[_cdk_nag_263d9695.NagPack], jsii.get(self, "nagPacks"))


@jsii.data_type(
    jsii_type="@aws/pdk.pdk_nag.PDKNagAppProps",
    jsii_struct_bases=[_aws_cdk_ceddda9d.AppProps],
    name_mapping={
        "analytics_reporting": "analyticsReporting",
        "auto_synth": "autoSynth",
        "context": "context",
        "default_stack_synthesizer": "defaultStackSynthesizer",
        "outdir": "outdir",
        "policy_validation_beta1": "policyValidationBeta1",
        "post_cli_context": "postCliContext",
        "stack_traces": "stackTraces",
        "tree_metadata": "treeMetadata",
        "fail_on_error": "failOnError",
        "fail_on_warning": "failOnWarning",
        "nag_packs": "nagPacks",
    },
)
class PDKNagAppProps(_aws_cdk_ceddda9d.AppProps):
    def __init__(
        self,
        *,
        analytics_reporting: typing.Optional[builtins.bool] = None,
        auto_synth: typing.Optional[builtins.bool] = None,
        context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        default_stack_synthesizer: typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer] = None,
        outdir: typing.Optional[builtins.str] = None,
        policy_validation_beta1: typing.Optional[typing.Sequence[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]] = None,
        post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        stack_traces: typing.Optional[builtins.bool] = None,
        tree_metadata: typing.Optional[builtins.bool] = None,
        fail_on_error: typing.Optional[builtins.bool] = None,
        fail_on_warning: typing.Optional[builtins.bool] = None,
        nag_packs: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagPack]] = None,
    ) -> None:
        '''
        :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
        :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
        :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
        :param default_stack_synthesizer: The stack synthesizer to use by default for all Stacks in the App. The Stack Synthesizer controls aspects of synthesis and deployment, like how assets are referenced and what IAM roles to use. For more information, see the README of the main CDK package. Default: - A ``DefaultStackSynthesizer`` with default settings
        :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
        :param policy_validation_beta1: Validation plugins to run after synthesis. Default: - no validation plugins
        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
        :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
        :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
        :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
        :param nag_packs: Custom nag packs to execute. Default: DEFAULT_NAG_PACKS

        :inheritDoc: true
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73ff6b436e20d432d5ee6d09f9604df61e816b58f9601272a85d1cfceb83d7bc)
            check_type(argname="argument analytics_reporting", value=analytics_reporting, expected_type=type_hints["analytics_reporting"])
            check_type(argname="argument auto_synth", value=auto_synth, expected_type=type_hints["auto_synth"])
            check_type(argname="argument context", value=context, expected_type=type_hints["context"])
            check_type(argname="argument default_stack_synthesizer", value=default_stack_synthesizer, expected_type=type_hints["default_stack_synthesizer"])
            check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
            check_type(argname="argument policy_validation_beta1", value=policy_validation_beta1, expected_type=type_hints["policy_validation_beta1"])
            check_type(argname="argument post_cli_context", value=post_cli_context, expected_type=type_hints["post_cli_context"])
            check_type(argname="argument stack_traces", value=stack_traces, expected_type=type_hints["stack_traces"])
            check_type(argname="argument tree_metadata", value=tree_metadata, expected_type=type_hints["tree_metadata"])
            check_type(argname="argument fail_on_error", value=fail_on_error, expected_type=type_hints["fail_on_error"])
            check_type(argname="argument fail_on_warning", value=fail_on_warning, expected_type=type_hints["fail_on_warning"])
            check_type(argname="argument nag_packs", value=nag_packs, expected_type=type_hints["nag_packs"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if analytics_reporting is not None:
            self._values["analytics_reporting"] = analytics_reporting
        if auto_synth is not None:
            self._values["auto_synth"] = auto_synth
        if context is not None:
            self._values["context"] = context
        if default_stack_synthesizer is not None:
            self._values["default_stack_synthesizer"] = default_stack_synthesizer
        if outdir is not None:
            self._values["outdir"] = outdir
        if policy_validation_beta1 is not None:
            self._values["policy_validation_beta1"] = policy_validation_beta1
        if post_cli_context is not None:
            self._values["post_cli_context"] = post_cli_context
        if stack_traces is not None:
            self._values["stack_traces"] = stack_traces
        if tree_metadata is not None:
            self._values["tree_metadata"] = tree_metadata
        if fail_on_error is not None:
            self._values["fail_on_error"] = fail_on_error
        if fail_on_warning is not None:
            self._values["fail_on_warning"] = fail_on_warning
        if nag_packs is not None:
            self._values["nag_packs"] = nag_packs

    @builtins.property
    def analytics_reporting(self) -> typing.Optional[builtins.bool]:
        '''Include runtime versioning information in the Stacks of this app.

        :default: Value of 'aws:cdk:version-reporting' context key
        '''
        result = self._values.get("analytics_reporting")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def auto_synth(self) -> typing.Optional[builtins.bool]:
        '''Automatically call ``synth()`` before the program exits.

        If you set this, you don't have to call ``synth()`` explicitly. Note that
        this feature is only available for certain programming languages, and
        calling ``synth()`` is still recommended.

        :default:

        true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false``
        otherwise
        '''
        result = self._values.get("auto_synth")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def context(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''Additional context values for the application.

        Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence.

        Context can be read from any construct using ``node.getContext(key)``.

        :default: - no additional context
        '''
        result = self._values.get("context")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def default_stack_synthesizer(
        self,
    ) -> typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer]:
        '''The stack synthesizer to use by default for all Stacks in the App.

        The Stack Synthesizer controls aspects of synthesis and deployment,
        like how assets are referenced and what IAM roles to use. For more
        information, see the README of the main CDK package.

        :default: - A ``DefaultStackSynthesizer`` with default settings
        '''
        result = self._values.get("default_stack_synthesizer")
        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer], result)

    @builtins.property
    def outdir(self) -> typing.Optional[builtins.str]:
        '''The output directory into which to emit synthesized artifacts.

        You should never need to set this value. By default, the value you pass to
        the CLI's ``--output`` flag will be used, and if you change it to a different
        directory the CLI will fail to pick up the generated Cloud Assembly.

        This property is intended for internal and testing use.

        :default:

        - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``.
        If ``CDK_OUTDIR`` is not defined, uses a temp directory.
        '''
        result = self._values.get("outdir")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def policy_validation_beta1(
        self,
    ) -> typing.Optional[typing.List[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]]:
        '''Validation plugins to run after synthesis.

        :default: - no validation plugins
        '''
        result = self._values.get("policy_validation_beta1")
        return typing.cast(typing.Optional[typing.List[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]], result)

    @builtins.property
    def post_cli_context(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''Additional context values for the application.

        Context provided here has precedence over context set by:

        - The CLI via --context
        - The ``context`` key in ``cdk.json``
        - The ``AppProps.context`` property

        This property is recommended over the ``AppProps.context`` property since you
        can make final decision over which context value to take in your app.

        Context can be read from any construct using ``node.getContext(key)``.

        :default: - no additional context

        Example::

            // context from the CLI and from `cdk.json` are stored in the
            // CDK_CONTEXT env variable
            const cliContext = JSON.parse(process.env.CDK_CONTEXT!);
            
            // determine whether to take the context passed in the CLI or not
            const determineValue = process.env.PROD ? cliContext.SOMEKEY : 'my-prod-value';
            new App({
              postCliContext: {
                SOMEKEY: determineValue,
              },
            });
        '''
        result = self._values.get("post_cli_context")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def stack_traces(self) -> typing.Optional[builtins.bool]:
        '''Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs.

        :default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
        '''
        result = self._values.get("stack_traces")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def tree_metadata(self) -> typing.Optional[builtins.bool]:
        '''Include construct tree metadata as part of the Cloud Assembly.

        :default: true
        '''
        result = self._values.get("tree_metadata")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def fail_on_error(self) -> typing.Optional[builtins.bool]:
        '''Determines whether any errors encountered should trigger a test failure.

        :default: false
        '''
        result = self._values.get("fail_on_error")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def fail_on_warning(self) -> typing.Optional[builtins.bool]:
        '''Determines whether any warnings encountered should trigger a test failure.

        :default: false
        '''
        result = self._values.get("fail_on_warning")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def nag_packs(self) -> typing.Optional[typing.List[_cdk_nag_263d9695.NagPack]]:
        '''Custom nag packs to execute.

        :default: DEFAULT_NAG_PACKS
        '''
        result = self._values.get("nag_packs")
        return typing.cast(typing.Optional[typing.List[_cdk_nag_263d9695.NagPack]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PDKNagAppProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "AwsPrototypingChecks",
    "ExtendedNagResult",
    "Message",
    "NagResult",
    "NagResultCompliance",
    "PDKNag",
    "PDKNagApp",
    "PDKNagAppProps",
]

publication.publish()

def _typecheckingstub__b8aa12b05f34ae8c5f2ba1473e38e19d866fb8f4b520412005d0fe346b7fb8e7(
    node: _constructs_77d1e7e8.IConstruct,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8449c5c2cfffdf3f73061d623bdbfb9a6f8c1a04846ab12f3c08d754a61977e5(
    *,
    compliance: NagResultCompliance,
    nag_pack_name: builtins.str,
    resource: _aws_cdk_ceddda9d.CfnResource,
    rule_explanation: builtins.str,
    rule_id: builtins.str,
    rule_info: builtins.str,
    rule_level: _cdk_nag_263d9695.NagMessageLevel,
    rule_original_name: builtins.str,
    error_message: typing.Optional[builtins.str] = None,
    finding_id: typing.Optional[builtins.str] = None,
    suppression_reason: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c93182a4922d7452f57be229082f9c3d5dd9ca71941154fcdac4df76b43c528(
    *,
    message_description: builtins.str,
    message_type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83f28e99b6450320d049052294b8732c9914971212aecba15ae4e76747213125(
    *,
    messages: typing.Sequence[typing.Union[Message, typing.Dict[builtins.str, typing.Any]]],
    resource: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6df4154748281a399576171b2f69c41577cb5a8b1ea4b026921fbf1e7feed914(
    stack: _aws_cdk_ceddda9d.Stack,
    path: builtins.str,
    suppressions: typing.Sequence[typing.Union[_cdk_nag_263d9695.NagPackSuppression, typing.Dict[builtins.str, typing.Any]]],
    apply_to_children: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9c7b8ca6e6cf7067508e077a349f6970a468d6f27683ecf2baab2767c4a24e6(
    stack: _aws_cdk_ceddda9d.Stack,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0aa0bbf9e40945577406f43f4ea42623d4fe13e5e55279a3613263349deeea63(
    stack: _aws_cdk_ceddda9d.Stack,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3571ab007307dce3ff9ffc4cbe7060b3eb33d9a5019948d82aca2dd1edf04c18(
    stack: _aws_cdk_ceddda9d.Stack,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f9f55608ad622f385b97d568c1b49a24059612e0fe4dde7d461d193d8779f26(
    stack: _aws_cdk_ceddda9d.Stack,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2fcf25e53176b62e6528f199f19b5eb0ba7082819a349f5a61264769c40505e(
    *results: ExtendedNagResult,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73ff6b436e20d432d5ee6d09f9604df61e816b58f9601272a85d1cfceb83d7bc(
    *,
    analytics_reporting: typing.Optional[builtins.bool] = None,
    auto_synth: typing.Optional[builtins.bool] = None,
    context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
    default_stack_synthesizer: typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer] = None,
    outdir: typing.Optional[builtins.str] = None,
    policy_validation_beta1: typing.Optional[typing.Sequence[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]] = None,
    post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
    stack_traces: typing.Optional[builtins.bool] = None,
    tree_metadata: typing.Optional[builtins.bool] = None,
    fail_on_error: typing.Optional[builtins.bool] = None,
    fail_on_warning: typing.Optional[builtins.bool] = None,
    nag_packs: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagPack]] = None,
) -> None:
    """Type checking stubs"""
    pass
